@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc
 version: 1.17.0.3
-id: pandoc-1.17.0.3-eb510c613bb58261320cda2a21b65c87
-key: pando_2AaKh2NjLYHBGK7r2eukD3
+id: pandoc-1.17.0.3-385c8e8a07c6129d5c295aa0dcb411ba
+key: pando_BkWw02DkR2Q63WYqAVSaJD
 license: GPL
 copyright: (c) 2006-2016 John MacFarlane
 maintainer: John MacFarlane <jgm@berkeley.edu>
@@ -85,22 +85,22 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
 data-dir: /usr/share/pandoc
-hs-libraries: HSpandoc-1.17.0.3-2AaKh2NjLYHBGK7r2eukD3
+hs-libraries: HSpandoc-1.17.0.3-BkWw02DkR2Q63WYqAVSaJD
 depends:
-    HTTP-4000.3.3-e80abaf8bcce3e49baa17e1fe8d694c7
+    HTTP-4000.3.3-19714fd075f563d66508acf4bb5a7081
     JuicyPixels-3.2.7-7a5ea2c8822f98f6d9837c143b0f3055
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
+    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     cmark-0.5.2-f48a7256a8c75efe8918f0ce1d08f0cd
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     extensible-exceptions-0.1.1.4-8159918b63d70675389129eaecbf720a
@@ -108,30 +108,30 @@ depends:
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     haddock-library-1.2.1-51a4bfa148b95520f3c56461f9e3c4f2
-    highlighting-kate-0.6.2-78975d33e6a60b626b8bbe418bb316e1
+    highlighting-kate-0.6.2-78db503a6c292fc9bc7310d5e0df6db9
     hslua-0.4.1-5acb63b51e4a9d39e9aa4a0ad9006234
-    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
-    http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    http-client-0.4.28-3a5d04f7eb5922409c889a37b339ae0f
+    http-client-tls-0.2.4-ad0e9a866e1feb2eac114d565c18f6c6
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
+    network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
-    pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    pandoc-types-1.16.1-30bcf2ba2a8f2fe5e0ad6c109c33aa1e
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
+    tagsoup-0.13.10-e0607642a7a600be1f9d9bab46fd617e
     temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
-    texmath-0.8.6.1-5f9e05ceca1cc643ef8bc76de94907d1
+    texmath-0.8.6.2-a3b68b8ea0b0cf165235dc5ba9c78e82
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
-    yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
+    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
     zip-archive-0.3.0.2-15b8e9a70ed3ab3db3683741297aa226
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
